#ifndef LIBJSONHANDLE_HELP_H
#define LIBJSONHANDLE_HELP_H

#include <iostream>


class Help {

public:
    static void showHelp(const std::string& option);

};

#endif //LIBJSONHANDLE_HELP_H